@@ -2,8 +2,8 @@ import pandas as pd
 
 import logging
 
-from ...uri import parse_uri
-from .base import Adapter, register_adapter
+from tableconv.uri import parse_uri
+from tableconv.adapters.df.base import Adapter, register_adapter
 
 
 logger = logging.getLogger(__name__)
