@@ -2,7 +2,7 @@ from typing import List, Optional
 
 import pandas as pd
 
-from ...in_memory_query import query_in_memory
+from tableconv.in_memory_query import query_in_memory
 
 
 class NoConfigurationOptionsAvailable(Exception):
@@ -31,7 +31,7 @@ class Adapter:
         raise NotImplementedError(f'get_example_url not defined for {scheme}')
 
     @classmethod
-    def load(cls, uri: str, query: str) -> pd.DataFrame:
+    def load(cls, uri: str, query: Optional[str]) -> pd.DataFrame:
         raise NotImplementedError
 
     @classmethod
