@@ -1,15 +1,21 @@
 
-from .base import Adapter, register_adapter
-from .file_adapter_mixin import FileAdapterMixin
+from tableconv.adapters.df.base import Adapter, register_adapter
+from tableconv.adapters.df.file_adapter_mixin import FileAdapterMixin
 
 
+# @register_write_adapter(
+#    protocol='sql_values', aliases=[], parameters={}, example_url='', text_based=True, file_based=True)
 @register_adapter(['sql_values'], write_only=True)
 class SQLLiteralAdapter(FileAdapterMixin, Adapter):
-    """ Currently only supports Postgres-flavored VALUES syntax"""
+    """ Currently only supports the PostgreSQL-flavored VALUES syntax"""
     text_based = True
 
     @staticmethod
-    def dump_text_data(df, scheme, kwargs):
+    def get_example_url(scheme):
+        return f'{scheme}:-'
+
+    @staticmethod
+    def dump_text_data(df, scheme, params):
         data = df.to_dict(orient='split')
 
         table_name = 'data'
